.. marshmallow documentation master file

********************************************
marshmallow: simplified object serialization
********************************************

Release v\ |version|. (:ref:`Changelog <changelog>`)

.. include:: about.rst.inc

Upgrading from an older version?
================================

See the :ref:`Upgrading to Newer Releases <upgrading>` page for notes on getting your code up-to-date with the latest version.

Why another library?
=====================

See :ref:`this document <why>` to learn about what makes marshmallow unique.


Guide
=====

.. toctree::
    :maxdepth: 2

    install
    quickstart
    nesting
    custom_fields
    extending
    examples


API Reference
=============

.. toctree::
    :maxdepth: 2

    api_reference

Project Info
============

.. toctree::
    :maxdepth: 1

    why
    changelog
    upgrading
    ecosystem
    license
    authors
    contributing
    code_of_conduct
    kudos
